==> Mudlib-CD.00.28.tar.gz: lib/std/living.c <==
/* 
 * /std/living.c
 *
 * Contains all routines relating to living objects of any kind.
 *
 * If you are going to copy this file, in the purpose of changing
 * it a little to your own need, beware:
 *
 * First try one of the following:
 *
 * 1. Do clone_object(), and then configure it. This object is specially
 *    prepared for configuration.
 *
 * 2. If you still is not pleased with that, create a new empty
 *    object, and make an inheritance of this object on the first line.
 *    This will automatically copy all variables and functions from the
 *    original object. Then, add the functions you want to change. The
 *    original function can still be accessed with '::' prepended on the name.
 *
 * The maintainer of this LPmud might become sad with you if you fail
 * to do any of the above. Ask other wizards if you are doubtful.
 *   
 * The reason of this, is that the above saves a lot of memory.
 */
#pragma save_binary

inherit "/std/container";

#include <std.h>
#include <log.h>		/* What shall we log */
#include <macros.h>
#include <stdproperties.h>
#include <formulas.h>		/* All game formulas, ex: combat */
#include <language.h>
#include <living_desc.h>	/* All text constants */

#undef DO_PROFILE "/std/living"
#include "/lib/profile.c"
#include "/std/living/living.h"
#include "/std/living/savevars.c"
#include "/std/living/combat.c"
#include "/std/living/move.c"
#include "/std/living/gender.c"
#include "/std/living/stats.c"
#include "/std/living/carry.c"
#include "/std/living/heart_beat.c"
#include "/std/living/drink_eat.c"
#include "/std/living/cmdhooks.c"
#include "/std/living/description.c"
#include "/std/living/tasks.c"
#include "/std/living/wizstat.c"
#include "/std/living/spells.c"
#include "/std/living/possess.c"
#include "/std/living/notify_meet.c"

static int tell_active_flag;      /* Flag to check in catch_msg() */

/*
 * Function name: create_container
 * Description:   Create the living object. (constructor)
 */
nomask void
create_container()
{
    start_profiling();
    PROFILE("create");

    if (SECURITY->check_inherit("/std/living", this_object()))
	remove_object();

    save_vars_reset();
    notify_meet_reset();
    gender_reset();
    spells_reset();
    ss_reset(); 
    carry_reset();
    drink_eat_reset();

    add_prop(LIVE_I_IS, 1);	/* We are alive! 8) */
    add_prop(CONT_I_ATTACH, 1);	/* livings carry inventory on the outside */
    add_prop(CONT_I_HIDDEN, 1);	/* livings cant see what other livings carry */
    add_prop(CONT_I_REDUCE_WEIGHT, 200); /* items in bags make us carry twice */
    add_prop(CONT_I_REDUCE_VOLUME, 200); /* as much as usually. */

    create_living();

    if (!geteuid(this_object()))   /* Get our own uid if not prepared */
    { 
	setuid(); 
	seteuid(getuid(this_object()));
    }

    combat_reset();

    enable_commands();
    cmdhooks_reset();
    move_reset(); 
}

/*
 * Function name: create_living
 * Description:   Create the living object. (standard)
 */
public void
create_living()
{
    ::create_container();
    set_name("living");	/* Default name for living objects */
}

/*
 * Function name: reset_container
 * Description:   Reset the living object. 
 */
public nomask void
reset_container() { reset_living(); }

/*
 * Function name: reset_living
 * Description:   Reset the living object. (standard)
 */
public void
reset_living() { ::reset_container(); }

/*
 * Function name: init
 * Description:   Tells us of new players in our neigbourhood
 */
nomask void
init()
{
    PROFILE("init");

    ::init();
    combat_init();
    start_heart();
    notify_meet_init();
    this_object()->init_living();
}

/*
 * Function name: encounter
 * Description:   Called when encountering an object
 */
public void
encounter(object obj)
{
    obj->init();
}

/*
 * Function name:	command
 * Description:		Makes the living object execute a command
 * Arguments:		cmd: String containing the command
 * Returns:		eval_cost or '0' if unsuccessfull
 */
public int
command(string cmd)
{
    return efun::command(cmd);
}

/*
 * Function name: catch_msg
 * Description:   This function is called for every normal message sent
 *                to this living. The only exception is efun tell_object()
 *		  and write() which go through catch_tell().
 * Arguments:     str:       Message to tell the player
 *                from_player: The object that generated the message
 *			     This is only valid if the message is on the
 *			     form ({ "met message", "unmet message",
 *				     "unseen message" })
 */
public void 
catch_msg(mixed str, object from_player)
{
    string euid;

    PROFILE("catch_msg");

    if (!query_ip_number(this_object()) && !query_tell_active())
	return;

    if (pointerp(str))
    {
	if (!from_player)
	    from_player = this_player();
	if ((sizeof(str) > 2) && (!CAN_SEE_IN_ROOM(this_object()) ||
		!CAN_SEE(this_object(), from_player)))
	    tell_object(this_object(), str[2]);
	else if (this_object()->query_met(from_player))
	    tell_object(this_object(), str[0]);
	else 
	    tell_object(this_object(), str[1]);
    }
    else
    {
	/* Swap euid to something harmeless as the VBFC calls can be done to
	   any function in any object in the game.
	*/
	euid = geteuid(this_object());
	seteuid(0);
	call_out("reset_euid", 1);
	tell_object(this_object(), process_string(str));
	seteuid(euid);
	remove_call_out("reset_euid");
    }
}

/*
 * Function name: remove_object
 * Description:   Destruct this object, but check for possessed first
 */
public int
remove_object()
{
    PROFILE("remove_object");
    possessed_remove();
    return ::remove_object();
}

/*
 * Function name: modify_command
 * Description:	 This is here so that a possessing wizard will get commands.
 *    Technically, it should be part of /std/living/possess.c, but since
 *    the lfun is more general, it is left here.
 */
string
modify_command(string cmd)
{
    return cmd;
}

/*
 * Function name: local_cmd()
 * Description:   Return a list of all add_actioned commands
 */

nomask string *
local_cmd()
{
    return get_localcmd();
}

/*
 * Function name: set_tell_active
 * Description:   Sets the tell_active_flag so that catch_msg() will send
 *                all messages to us.
 * Arguments:     i - a number, 1 or 0, on or off
 */
void set_tell_active(int i) { tell_active_flag = i; }

/*
 * Functione name: query_tell_active
 * Description:    Query the tell_active_flag
 * Returns:        The flag
 */
int query_tell_active() { return tell_active_flag; }

==> Mudlib-CD.00.30.tar.gz: lib/std/living.c <==
/* 
 * /std/living.c
 *
 * Contains all routines relating to living objects of any kind.
 *
 * If you are going to copy this file, in the purpose of changing
 * it a little to your own need, beware:
 *
 * First try one of the following:
 *
 * 1. Do clone_object(), and then configure it. This object is specially
 *    prepared for configuration.
 *
 * 2. If you still is not pleased with that, create a new empty
 *    object, and make an inheritance of this object on the first line.
 *    This will automatically copy all variables and functions from the
 *    original object. Then, add the functions you want to change. The
 *    original function can still be accessed with '::' prepended on the name.
 *
 * The maintainer of this LPmud might become sad with you if you fail
 * to do any of the above. Ask other wizards if you are doubtful.
 *   
 * The reason of this, is that the above saves a lot of memory.
 */
#pragma save_binary

inherit "/std/container";

#include <std.h>
#include <log.h>		/* What shall we log */
#include <macros.h>
#include <stdproperties.h>
#include <formulas.h>		/* All game formulas, ex: combat */
#include <language.h>
#include <living_desc.h>	/* All text constants */

#undef DO_PROFILE "/std/living"
#include "/lib/profile.c"
#include "/std/living/living.h"
#include "/std/living/savevars.c"
#include "/std/living/combat.c"
#include "/std/living/move.c"
#include "/std/living/gender.c"
#include "/std/living/stats.c"
#include "/std/living/carry.c"
#include "/std/living/heart_beat.c"
#include "/std/living/drink_eat.c"
#include "/std/living/cmdhooks.c"
#include "/std/living/description.c"
#include "/std/living/tasks.c"
#include "/std/living/wizstat.c"
#include "/std/living/spells.c"
#include "/std/living/possess.c"
#include "/std/living/notify_meet.c"

static int tell_active_flag;      /* Flag to check in catch_msg() */

/*
 * Function name: create_container
 * Description:   Create the living object. (constructor)
 */
nomask void
create_container()
{
    start_profiling();
    PROFILE("create");

    if (SECURITY->check_inherit("/std/living", this_object()))
	remove_object();

    save_vars_reset();
    notify_meet_reset();
    gender_reset();
    spells_reset();
    ss_reset(); 
    carry_reset();
    drink_eat_reset();

    add_prop(LIVE_I_IS, 1);	/* We are alive! 8) */
    add_prop(CONT_I_ATTACH, 1);	/* livings carry inventory on the outside */
    add_prop(CONT_I_HIDDEN, 1);	/* livings cant see what other livings carry */
    add_prop(CONT_I_REDUCE_WEIGHT, 200); /* items in bags make us carry twice */
    add_prop(CONT_I_REDUCE_VOLUME, 200); /* as much as usually. */

    create_living();

    if (!geteuid(this_object()))   /* Get our own uid if not prepared */
    { 
	setuid(); 
	seteuid(getuid(this_object()));
    }

    combat_reset();

    enable_commands();
    cmdhooks_reset();
    move_reset(); 
}

/*
 * Function name: create_living
 * Description:   Create the living object. (standard)
 */
public void
create_living()
{
    ::create_container();
    set_name("living");	/* Default name for living objects */
}

/*
 * Function name: reset_container
 * Description:   Reset the living object. 
 */
public nomask void
reset_container() { reset_living(); }

/*
 * Function name: reset_living
 * Description:   Reset the living object. (standard)
 */
public void
reset_living() { ::reset_container(); }

/*
 * Function name: init
 * Description:   Tells us of new players in our neigbourhood
 */
nomask void
init()
{
    PROFILE("init");

    ::init();
    combat_init();
    start_heart();
    notify_meet_init();
    this_object()->init_living();
}

/*
 * Function name: encounter
 * Description:   Called when encountering an object
 */
public void
encounter(object obj)
{
    obj->init();
}

/*
 * Function name:	command
 * Description:		Makes the living object execute a command
 * Arguments:		cmd: String containing the command
 * Returns:		eval_cost or '0' if unsuccessfull
 */
public int
command(string cmd)
{
    return efun::command(cmd);
}

/*
 * Function name: catch_msg
 * Description:   This function is called for every normal message sent
 *                to this living.
 * Arguments:     str:       Message to tell the player
 *                from_player: The object that generated the message
 *			     This is only valid if the message is on the
 *			     form ({ "met message", "unmet message",
 *				     "unseen message" })
 */
public void 
catch_msg(mixed str, object from_player)
{
    string euid;

    PROFILE("catch_msg");

    if (!query_ip_number(this_object()) && !query_tell_active())
	return;

    if (pointerp(str))
    {
	if (!from_player)
	    from_player = this_player();
	if ((sizeof(str) > 2) && (!CAN_SEE_IN_ROOM(this_object()) ||
		!CAN_SEE(this_object(), from_player)))
	    write_socket(str[2]);
	else if (this_object()->query_met(from_player))
	    write_socket(str[0]);
	else 
	    write_socket(str[1]);
    }
    else
    {
	write_socket(process_string(str, 1));
    }
}

/*
 * Function name: remove_object
 * Description:   Destruct this object, but check for possessed first
 */
public int
remove_object()
{
    PROFILE("remove_object");
    possessed_remove();
    if (query_combat_object())
	catch(query_combat_object()->remove_object());
    return ::remove_object();
}

/*
 * Function name: modify_command
 * Description:	 This is here so that a possessing wizard will get commands.
 *    Technically, it should be part of /std/living/possess.c, but since
 *    the lfun is more general, it is left here.
 */
string
modify_command(string cmd)
{
    return cmd;
}

/*
 * Function name: local_cmd()
 * Description:   Return a list of all add_actioned commands
 */

nomask string *
local_cmd()
{
    return get_localcmd();
}

/*
 * Function name: set_tell_active
 * Description:   Sets the tell_active_flag so that catch_msg() will send
 *                all messages to us.
 * Arguments:     i - a number, 1 or 0, on or off
 */
void set_tell_active(int i) { tell_active_flag = i; }

/*
 * Functione name: query_tell_active
 * Description:    Query the tell_active_flag
 * Returns:        The flag
 */
int query_tell_active() { return tell_active_flag; }
